"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContainerPlugin = void 0;
const base_1 = require("../builtin-plugin/base");
const config_1 = require("../config");
const util_1 = require("../util");
const options_1 = require("../container/options");
class ContainerPlugin extends base_1.RspackBuiltinPlugin {
    constructor(options) {
        super();
        this.name = base_1.BuiltinPluginName.ContainerPlugin;
        this._options = {
            name: options.name,
            shareScope: options.shareScope || "default",
            library: options.library || {
                type: "var",
                name: options.name
            },
            runtime: options.runtime,
            filename: options.filename,
            exposes: (0, options_1.parseOptions)(options.exposes, item => ({
                import: Array.isArray(item) ? item : [item],
                name: undefined
            }), item => ({
                import: Array.isArray(item.import) ? item.import : [item.import],
                name: item.name || undefined
            }))
        };
    }
    raw(compiler) {
        const { name, shareScope, library, runtime, filename, exposes } = this._options;
        if (!compiler.options.output.enabledLibraryTypes.includes(library.type)) {
            compiler.options.output.enabledLibraryTypes.push(library.type);
        }
        const rawOptions = {
            name,
            shareScope,
            library: (0, config_1.getRawLibrary)(library),
            runtime: !(0, util_1.isNil)(runtime) ? (0, config_1.getRawEntryRuntime)(runtime) : undefined,
            filename,
            exposes: exposes.map(([key, r]) => ({ key, ...r }))
        };
        return {
            name: this.name,
            options: rawOptions
        };
    }
}
exports.ContainerPlugin = ContainerPlugin;
